Example Output
==============

Below shows an example of the output you might expect, courtesy of a sample
Chalice project. Take a look at the source code in the chalicedoc repository
to see what's going on.

.. chalice:project:: tests/test-project/sample
